@@ -1,5 +1,5 @@
 from urllib import parse
-import urllib,pygame
+import urllib,pygame,os
 import contextlib
 import wave
 import urllib.request
@@ -16,13 +16,6 @@ import json,time
 speaker=1
 ak=urllib.request.urlopen("http://www.asunc.cn/ak.txt").read().decode("utf-8")
 ak=json.loads(ak)['ak']
-def setvoicemode(gender):
-    if gender != "boy" and gender != "girl":
-        raise Exception("参数必须为boy(男人)或者girl(女人)")
-    if gender=='boy':
-        speaker=1
-    if gender=='girl':
-        speaker=5
 def get_ipaddress(ip, getpoint=False):
     if ip.count(".") != 3:
         return -1
@@ -77,6 +70,8 @@ def makevoice(text, filename,mode=1,speed=40):
     nonce_s = m.hexdigest()
     nonce_s = nonce_s[0:random.randint(1, 31)]
     vmv='1'
+    filename=str(filename)
+    text=str(text)
     if filename[len(filename)-4]=='.':
         if filename[len(filename)-3]=='p' or filename[len(filename)-3]=='P':
             wmv='1'
@@ -117,7 +112,7 @@ def makevoice(text, filename,mode=1,speed=40):
         fout.close()
         return res_dict['ret']
     else:
-        return res_dict['ret']
+        return -1
 def speak(text,mode=1,speed=40):
     def getReqSign(params, key):
         dict_kl = sorted(params)
@@ -156,9 +151,8 @@ def speak(text,mode=1,speed=40):
               }
     params['sign'] = getReqSign(params, appkey)
     s = urlencode(params)
-    res = urlopen(url, s.encode())  # 网络请求
-    res_str = res.read().decode()
-    res_dict = eval(res_str)
+    res = urlopen(url, s.encode()).read().decode()
+    res_dict = eval(res)
     if res_dict['ret'] == 0:
         res_data = res_dict['data']
         res_data_format = res_data['format']
@@ -175,6 +169,7 @@ def speak(text,mode=1,speed=40):
             import wave
             fr = wave.open('alsovoice.wav', 'rb')
             secs = fr.getnframes() / fr.getframerate()
+            fr.close()
             pygame.mixer.init()
             pygame.mixer.music.load("alsovoice.wav")
             pygame.mixer.music.play()
@@ -183,6 +178,54 @@ def speak(text,mode=1,speed=40):
         except:
             return -1
     else:
-        return res_dict['ret']
+        return -1
+def AI_chat(text,is_speak=False,mode=5):
+    def getReqSign(params, key):
+        dict_kl = sorted(params)
+        s = ''
+        for k in dict_kl:
+            v = params[k]
+            if v != '':
+                v0 = str(quote_plus(str(v)))
+                s = s + k + '=' + v0 + '&'
+        s = s + 'app_key=' + key;
+        m = hashlib.md5()
+        m.update(s.encode("utf8"))
+        sign = m.hexdigest()
+        sign = sign.upper()
+        return sign
+
+    app = json.loads(urlopen("http://www.asunc.cn/ten.txt").read().decode("utf-8"))
+    appid = app['appid']
+    appkey = app['appkey']
+    url = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_textchat'
+    time_s = int(time.time())
+    m = hashlib.md5()
+    m.update(str(time_s).encode("utf8"))
+    nonce_s = m.hexdigest()
+    nonce_s = nonce_s[0:random.randint(1, 31)]
+    params = {'app_id': appid,
+              'time_stamp': time_s,
+              'nonce_str': nonce_s,
+              'session': '0',
+              'sign': '',
+              'question': text
+              }
+    params['sign'] = getReqSign(params, appkey)
+    s = urlencode(params)
+    res = urlopen(url, s.encode())  # 网络请求
+    res_str = res.read().decode()
+    res_dict = eval(res_str)
+    if res_dict['ret']==0:
+        if is_speak==True:
+            if speak(res_dict['data']['answer'],mode)!=0:
+                return -1
+            else:
+                return 0
+        else:
+            return 0,res_dict['data']['answer']
+    else:
+        if res_dict['ret'] == 16394:
+            return 404
 def help():
-    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt"))
\ No newline at end of file
+    print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt").read().decode('gbk'))
\ No newline at end of file
